;; agents have a probablity to reproduce and a strategy
turtles-own [ PTR cooperate? partners partner1 partner2 partner3 partner4]

globals [
 meet ;; number of agent meetings
 cooperate  ;; number of CC outcomes
 totalTurtles
 totalCooperators 
]

to setup-empty
  ;; (for this model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  __clear-all-and-reset-ticks
 
end

;; creates a world with an agent on each patch
to setup-full
  setup-empty
  ask patches [ create-turtle ]
end

;; creates a new agent in the world
to create-turtle  ;; patch procedure
  sprout 1 [
    ;; determine the strategy for interacting with someone of the same color
    set cooperate? (random-float 1.0 < immigrant-chance-cooperate)
    ;; change the shape of the agent on the basis of the strategy
    update-color
    set partner1 -1
    set partner2 -1
    set partner3 -1
    set partner4 -1
    set partners 0
    add-partners 
    
  ]
end


to add-partners
  if(count turtles-on neighbors4 != 0) [
    let temp turtles-on neighbors4
    ;ask temp [show partners]
    ;ask one-of turtles-on neighbors4 with [partners < max-partners] [
    ask temp with [partners < max-partners] [  
       let myID [who] of myself
       let alreadyPartners false
       if(myID = partner1 or myID = partner2 or myID = partner3 or myID = partner4)[set alreadyPartners true ]
       
       if([partners] of myself < max-partners and alreadyPartners = false)[
       ;; this makes the calling turtle a partner of the other
       ifelse(partner1 = -1) [
          set partner1 myID 
         ]
       [
        ifelse(partner2 = -1) [set partner2 myID ]
        [ 
          ifelse(partner3 = -1) [set partner3 myID 
         ]
          [ set partner4 myID ] 
         ] 
       ]
       set partners partners + 1
      
      ;; this makes the other a partner of the calling turtle
      let partnerID who
       ifelse([partner1] of myself = -1) [
          ask myself [set partner1 partnerID] 
       ]
       [
       ifelse([partner2] of myself = -1) [ ask myself [set partner2 partnerID] 
       ]
       [
        ifelse([partner3] of myself = -1) [ ask myself [set partner3 partnerID] 
        ]     
        [ ask myself [set partner4 partnerID] ]
       ]
      
      ]
        ask myself [set partners partners + 1]
    ]
   ]
  ]
end 


;; the main routine
to go
  immigrate       ;; new agents immigrate into the world

  ;; reset the probability to reproduce
  ask turtles [ set PTR initial-PTR ]

  ;; have all of the agents interact with other agents if they can
  ask turtles [ interact ]
  ;; now they reproduce
  ask turtles [ reproduce ]
  death           ;; kill some of the agents
  ifelse(stochastic = false) [
    ask turtles [ add-partners ]
  ]
  ;stochastic = true
  [ 
   ask turtles [
    set partner1 -1
    set partner2 -1
    set partner3 -1
    set partner4 -1
    set partners 0
   ]
  ]
  
  if(ticks = 2000) [ 
    set meet 0 
    set cooperate 0
    set totalTurtles 0
    set totalCooperators 0
    ] 
  if(ticks > 2000) [
    set totalTurtles totalTurtles + count turtles
    set totalCooperators totalCooperators + count turtles with [cooperate? = true]     
  ]    
  if(ticks = 2100) [
    ;file-open "cooperation.txt"
    file-open "H:\\deterministic vs stochastic abm\\cooperation4fg.txt"
    file-write behaviorspace-run-number 
    file-write max-partners
    file-write stochastic
    file-write cost-of-giving
    file-write meet
    file-write cooperate
    file-write totalTurtles
    file-write totalCooperators
    file-print " "  
    file-close
  ]  
  
  
  
  tick
end


;; random individuals enter the world on empty cells
to immigrate
  
  let immigrants-per-day-temp 0
  ifelse immigrants-per-day < 1 [
    let y random-float 1
    ifelse y > .5 [ set immigrants-per-day-temp 1]
    [ set immigrants-per-day-temp 0]
  ]
  [
    set immigrants-per-day-temp immigrants-per-day
  ]
  
  let empty-patches patches with [not any? turtles-here]
  ;; we can't have more immigrants than there are empty patches
  let how-many min list immigrants-per-day-temp (count empty-patches)
  ask n-of how-many empty-patches [ create-turtle ]
end

to interact  ;; turtle procedure
  ifelse(stochastic = true) [interact-stochastic ]
  [ interact-deterministic ]


end


to interact-deterministic
      
      ;; counting for deterministic double counts everything, so need to divide by two to get the true 
      ;; number for meet and cooperate
      
      let p1 partner1
      let p2 partner2
      let p3 partner3
      let p4 partner4
      
      ask turtles with [who = p1]  [
       set meet meet + 1  
       ;; if I cooperate then I reduce my PTR and increase my neighbors
       if [cooperate?] of myself [
        ask myself [ set PTR PTR - cost-of-giving  ]  
        set PTR PTR + gain-of-receiving               
        if(cooperate?) [set cooperate cooperate + 1] 
       ]
      ] 
      ask turtles with [who = p2]  [
       set meet meet + 1  
       ;; if I cooperate then I reduce my PTR and increase my neighbors
       if [cooperate?] of myself [
        ask myself [ set PTR PTR - cost-of-giving ]     
        set PTR PTR + gain-of-receiving 
        if(cooperate?) [set cooperate cooperate + 1]               
       ]
      ]
      ask turtles with [who = p3]  [
        set meet meet + 1   
       ;; if I cooperate then I reduce my PTR and increase my neighbors
       if [cooperate?] of myself [
        ask myself [ set PTR PTR - cost-of-giving ]     
        set PTR PTR + gain-of-receiving 
        if(cooperate?) [set cooperate cooperate + 1]               
       ]
      ]
      ask turtles with [who = p4]  [
       set meet meet + 1   
       ;; if I cooperate then I reduce my PTR and increase my neighbors
       if [cooperate?] of myself [
        ask myself [ set PTR PTR - cost-of-giving ]     
        set PTR PTR + gain-of-receiving 
        if(cooperate?) [set cooperate cooperate + 1]               
       ]
      ]
  
end

;; use PTR to determine if the agent gets to reproduce
to reproduce  ;; turtle procedure
  ;; if a random variable is less than the PTR the agent can reproduce
  if random-float 1.0 < PTR [
    ;; find an empty location to reproduce into
   
    ;; This code places the child in the Von Neumann neighborhood of the parent
    let destination one-of neighbors4 with [not any? turtles-here]

   
   
   
    if destination != nobody [
      ;; if the location exists hatch a copy of the current turtle in the new location
      ;;  but mutate the child
      hatch 1 [
        move-to destination
        set partner1 -1
        set partner2 -1
        set partner3 -1
        set partner4 -1
        set partners 0
        add-partners 
        mutate
      ]
    ]
  ]
end

;; modify the children of agents according to the mutation rate
to mutate  ;; turtle procedure
   ;; mutate the strategy flags;
  ;; use NOT to toggle the flag
  if random-float 1.0 < mutation-rate [
    set cooperate? not cooperate?
  ]
  ;; make sure the shape of the agent reflects its strategy
  update-color
end


to interact-stochastic
   let temp turtles-on neighbors4
   
   ask temp with [partners < max-partners]   [
       let myID [who] of myself
       let alreadyPartners false
       if(myID = partner1 or myID = partner2 or myID = partner3 or myID = partner4)[set alreadyPartners true ]
       
       if([partners] of myself < max-partners and alreadyPartners = false)[
       ;; this makes the calling turtle a partner of the other
       ifelse(partner1 = -1) [
          set partner1 myID 
         ]
       [
        ifelse(partner2 = -1) [set partner2 myID ]
        [ 
          ifelse(partner3 = -1) [set partner3 myID 
         ]
          [ set partner4 myID ] 
         ] 
       ]
       set partners partners + 1
      
      ;; this makes the other a partner of the calling turtle
      let partnerID who
       ifelse([partner1] of myself = -1) [
          ask myself [set partner1 partnerID] 
       ]
       [
       ifelse([partner2] of myself = -1) [ ask myself [set partner2 partnerID] 
       ]
       [
        ifelse([partner3] of myself = -1) [ ask myself [set partner3 partnerID] 
        ]     
        [ ask myself [set partner4 partnerID] ]
       ]
      
      ]
        ask myself [set partners partners + 1]
    
     
      ; if I cooperates
      if [cooperate?] of myself [
        ask myself [ set PTR PTR - cost-of-giving ]     
        set PTR PTR + gain-of-receiving                
       ] 
      ; if my partners cooperates
       if(cooperate?) [
        ask myself [ set PTR PTR + gain-of-receiving ]     
        set PTR PTR - cost-of-giving               
       ] 
       set meet meet + 1
       if([cooperate?] of myself and cooperate?) [set cooperate cooperate + 1]
       
       ]
   ]
  
  
end



to death
  ;; check to see if a random variable is less than the death rate for each agent
  ask turtles [
    if random-float 1.0 < death-rate [
    if(stochastic = false) [
    let myWho who
      
    ask turtles with [who = [partner1] of myself] [
        if(partner1 = myWho) [set partner1 -1]    
        if(partner2 = myWho) [set partner2 -1]    
        if(partner3 = myWho) [set partner3 -1]    
        if(partner4 = myWho) [set partner4 -1]
        set partners partners - 1
    ]  
    
    ask turtles with [who = [partner2] of myself] [
        if(partner1 = myWho) [set partner1 -1]    
        if(partner2 = myWho) [set partner2 -1]    
        if(partner3 = myWho) [set partner3 -1]    
        if(partner4 = myWho) [set partner4 -1]
        set partners partners - 1
    ] 
    
    ask turtles with [who = [partner3] of myself] [
        if(partner1 = myWho) [set partner1 -1]    
        if(partner2 = myWho) [set partner2 -1]    
        if(partner3 = myWho) [set partner3 -1]    
        if(partner4 = myWho) [set partner4 -1]
        set partners partners - 1
    ] 
      
    ask turtles with [who = [partner4] of myself] [
        if(partner1 = myWho) [set partner1 -1]    
        if(partner2 = myWho) [set partner2 -1]    
        if(partner3 = myWho) [set partner3 -1]    
        if(partner4 = myWho) [set partner4 -1]
        set partners partners - 1
    ]   
    ]
       die 
       
   ]
      
  ]
end




;; make sure the shape matches the strategy
to update-color
  ;; if the agent cooperates they are red
  ifelse cooperate? [
    set color red
  ]
  ;; if the agent doesn't cooperate they are blue
  [
    set color blue
  ]
end








; Copyright 2003 Uri Wilensky. All rights reserved.
; The full copyright notice is in the Information tab.
@#$#@#$#@
GRAPHICS-WINDOW
323
10
792
500
-1
-1
9.0
1
10
1
1
1
0
1
1
1
0
50
0
50
1
1
1
ticks
30.0

SLIDER
5
150
171
183
mutation-rate
mutation-rate
0.0
1.0
0.0050
0.0010
1
NIL
HORIZONTAL

SLIDER
5
184
171
217
death-rate
death-rate
0.0
1.0
0.1
0.05
1
NIL
HORIZONTAL

SLIDER
5
218
171
251
immigrants-per-day
immigrants-per-day
0.0
100.0
1
1.0
1
NIL
HORIZONTAL

SLIDER
172
150
318
183
initial-PTR
initial-PTR
0.0
1.0
0.12
0.01
1
NIL
HORIZONTAL

SLIDER
172
184
318
217
cost-of-giving
cost-of-giving
0.0
1.0
0.01
0.01
1
NIL
HORIZONTAL

SLIDER
172
218
318
251
gain-of-receiving
gain-of-receiving
0.0
1.0
0.03
0.01
1
NIL
HORIZONTAL

BUTTON
20
37
128
70
setup empty
setup-empty
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
221
37
294
70
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
6
323
318
525
Strategy Counts
time
count
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"CC" 1.0 0 -10899396 true "" ""
"CD" 1.0 0 -2674135 true "" ""
"DC" 1.0 0 -4079321 true "" ""
"DD" 1.0 0 -16777216 true "" ""
"Total" 1.0 0 -16777216 true "" ""

BUTTON
130
37
219
70
setup full
setup-full
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
5
252
318
285
immigrant-chance-cooperate
immigrant-chance-cooperate
0.0
1.0
0.5
0.01
1
NIL
HORIZONTAL

TEXTBOX
35
82
294
144
Circles cooperate with same color\nSquares defect with same color\nFilled-in shapes cooperate with different color\nEmpty shapes defect with different color\n
11
0.0
0

SLIDER
321
500
493
533
max-partners
max-partners
1
4
4
1
1
NIL
HORIZONTAL

SWITCH
493
501
625
534
stochastic
stochastic
1
1
-1000

MONITOR
626
502
763
547
cooperate %
count turtles with [cooperate? = true] / count turtles 
4
1
11

@#$#@#$#@
## WHAT IS IT?

This model extends the Wilenski coding of the Hammond and Axelrod (2006) model of ethnocentrism. The possibility of ethnocentric behavior has been removed from the model. Now, agents can interact stochastically or deterministically within their von Neumann neighborhood.

## HOW IT WORKS

See Bausch, Andrew W. “Stochastic vs. Deterministic Interactions in a Spatial Prisoner's Dilemma” for a full description of the model.

## HOW TO USE IT

To prepare the simulation for a new run, press SETUP EMPTY.  Press GO to start the simulation running, press GO again to stop it.

SETUP FULL will allow you to start with a full world of random agents.

COST-OF-GIVING indicates how much it costs an agent to cooperate with another agent.

GAIN-OF-RECEIVING indicates how much an agent gains if another agent cooperates with them.

IMMIGRANT-CHANCE-COOPERATE-WITH-SAME indicates the probability that an immigrating agent will have the COOPERATE-WITH-SAME? variable set to true.

IMMIGRANT-CHANCE-COOPERATE-WITH-DIFFERENT indicates the probability that an immigrating agent will have the COOPERATE-WITH-DIFFERENT? variable set to true.

max-partners is described in the paper listed above

stochastic turns stochastic interactions on. Otherwise, interactions will be deterministic.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
setup-full repeat 150 [ go ]
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="4partners" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 4
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="3partners" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 3
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2partners" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 2
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1partners" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 1
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="4partnersbc" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 4
ifelse(behaviorspace-run-number &lt; 201) [

set cost-of-giving 0.005
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set cost-of-giving 0.02
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="3partnersbc" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 3
ifelse(behaviorspace-run-number &lt; 201) [

set cost-of-giving 0.005
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
[
  set cost-of-giving 0.02
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2partnersbc" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 2
ifelse(behaviorspace-run-number &lt; 201) [

set cost-of-giving 0.005
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
[
  set cost-of-giving 0.02
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1partnersbc" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 1
ifelse(behaviorspace-run-number &lt; 201) [

set cost-of-giving 0.005
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
[
  set cost-of-giving 0.02
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="4partnersfg" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 4
ifelse(behaviorspace-run-number &lt; 201) [

set mutation-rate  0.0025
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set mutation-rate  0.01
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>mutation-rate</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="3partnersfg" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 3
ifelse(behaviorspace-run-number &lt; 201) [

set mutation-rate  0.0025
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set mutation-rate  0.01
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>mutation-rate</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2partnersfg" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 2
ifelse(behaviorspace-run-number &lt; 201) [

set mutation-rate  0.0025
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set mutation-rate  0.01
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>mutation-rate</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1partnersfg" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 1
ifelse(behaviorspace-run-number &lt; 201) [

set mutation-rate  0.0025
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set mutation-rate  0.01
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>mutation-rate</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="4partnershi" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 4
ifelse(behaviorspace-run-number &lt; 201) [

set immigrants-per-day 0.5
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set immigrants-per-day 2
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>immigrants-per-day</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="3partnershi" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 3
ifelse(behaviorspace-run-number &lt; 201) [

set immigrants-per-day 0.5
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set immigrants-per-day 2
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>immigrants-per-day</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2partnershi" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 2
ifelse(behaviorspace-run-number &lt; 201) [

set immigrants-per-day 0.5
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set immigrants-per-day 2
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>immigrants-per-day</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1partnershi" repetitions="400" runMetricsEveryStep="false">
    <setup>set max-partners 1
ifelse(behaviorspace-run-number &lt; 201) [

set immigrants-per-day 0.5
 ifelse(behaviorspace-run-number &lt; 101) [
  set stochastic true
 ]
 [
  set stochastic false
 ]
 ]
[
  set immigrants-per-day 2
  ifelse(behaviorspace-run-number &lt; 301) [
  set stochastic true
  ]
  [
   set stochastic false
  ]
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>immigrants-per-day</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="4partnersk" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 4
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="3partnersk" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 3
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2partnersk" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 2
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1partnersk" repetitions="200" runMetricsEveryStep="false">
    <setup>set max-partners 1
ifelse(behaviorspace-run-number &lt; 101) [
 set stochastic true
]
[
 set stochastic false
]
setup-empty</setup>
    <go>go</go>
    <timeLimit steps="2101"/>
    <metric>max-partners</metric>
    <metric>stochastic</metric>
    <metric>meet</metric>
    <metric>cooperate</metric>
    <metric>totalTurtles</metric>
    <metric>totalCooperators</metric>
    <enumeratedValueSet variable="gain-of-receiving">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-ptr">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrants-per-day">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="immigrant-chance-cooperate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cost-of-giving">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
